MockHostBindings

Struct MockHostBindings 

pub struct MockHostBindings { /* private fields */ }
Trait defining all host functions available to WASM smart contracts.

This trait serves as the source of truth for host function signatures and is implemented by:

  • WasmHostBindings: The production implementation that calls actual host functions via FFI
  • EmptyHostBindings: Stub implementations for non-WASM builds (panics if called)
  • MockHostBindings: Generated by mockall for unit testing (via #[automock])

Example

use xrpl_wasm_stdlib::host::{HostBindings, WasmHostBindings};

fn my_function<H: HostBindings>(host: &H) {
    unsafe {
        let mut buffer = [0u8; 8];
        let result = host.get_ledger_sqn(buffer.as_mut_ptr(), buffer.len());
        // ... use result
    }
}

// In production code:
let host = WasmHostBindings;
my_function(&host);

Implementations

Source

impl MockHostBindings

pub fn checkpoint(&mut self)

Validate that all current expectations for all methods have been satisfied, and discard them.

pub fn new() -> Self

Create a new mock object with no expectations.

This method will not be generated if the real struct already has a new method. However, it will be generated if the struct implements a trait with a new method. The trait’s new method can still be called like <MockX as TraitY>::new

Source

impl MockHostBindings

pub fn expect_get_ledger_sqn(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_ledger_sqn method

pub fn expect_get_parent_ledger_time(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_parent_ledger_time method

pub fn expect_get_parent_ledger_hash(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_parent_ledger_hash method

pub fn expect_get_base_fee(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_base_fee method

pub fn expect_amendment_enabled(&mut self) -> &mut Expectation

Create an Expectation for mocking the amendment_enabled method

pub fn expect_cache_ledger_obj(&mut self) -> &mut Expectation

Create an Expectation for mocking the cache_ledger_obj method

pub fn expect_get_tx_field(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_tx_field method

pub fn expect_get_current_ledger_obj_field(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_current_ledger_obj_field method

pub fn expect_get_ledger_obj_field(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_ledger_obj_field method

pub fn expect_get_tx_nested_field(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_tx_nested_field method

pub fn expect_get_current_ledger_obj_nested_field(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_current_ledger_obj_nested_field method

pub fn expect_get_ledger_obj_nested_field(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_ledger_obj_nested_field method

pub fn expect_get_tx_array_len(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_tx_array_len method

pub fn expect_get_current_ledger_obj_array_len(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_current_ledger_obj_array_len method

pub fn expect_get_ledger_obj_array_len(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_ledger_obj_array_len method

pub fn expect_get_tx_nested_array_len(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_tx_nested_array_len method

pub fn expect_get_current_ledger_obj_nested_array_len( &mut self, ) -> &mut Expectation

Create an Expectation for mocking the get_current_ledger_obj_nested_array_len method

pub fn expect_get_ledger_obj_nested_array_len(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_ledger_obj_nested_array_len method

pub fn expect_update_data(&mut self) -> &mut Expectation

Create an Expectation for mocking the update_data method

pub fn expect_compute_sha512_half(&mut self) -> &mut Expectation

Create an Expectation for mocking the compute_sha512_half method

pub fn expect_check_sig(&mut self) -> &mut Expectation

Create an Expectation for mocking the check_sig method

pub fn expect_account_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the account_keylet method

pub fn expect_amm_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the amm_keylet method

pub fn expect_check_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the check_keylet method

pub fn expect_credential_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the credential_keylet method

pub fn expect_delegate_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the delegate_keylet method

pub fn expect_deposit_preauth_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the deposit_preauth_keylet method

pub fn expect_did_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the did_keylet method

pub fn expect_escrow_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the escrow_keylet method

pub fn expect_line_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the line_keylet method

pub fn expect_mpt_issuance_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the mpt_issuance_keylet method

pub fn expect_mptoken_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the mptoken_keylet method

pub fn expect_nft_offer_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the nft_offer_keylet method

pub fn expect_offer_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the offer_keylet method

pub fn expect_oracle_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the oracle_keylet method

pub fn expect_paychan_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the paychan_keylet method

pub fn expect_permissioned_domain_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the permissioned_domain_keylet method

pub fn expect_signers_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the signers_keylet method

pub fn expect_ticket_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the ticket_keylet method

pub fn expect_vault_keylet(&mut self) -> &mut Expectation

Create an Expectation for mocking the vault_keylet method

pub fn expect_get_nft(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_nft method

pub fn expect_get_nft_issuer(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_nft_issuer method

pub fn expect_get_nft_taxon(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_nft_taxon method

pub fn expect_get_nft_flags(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_nft_flags method

pub fn expect_get_nft_transfer_fee(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_nft_transfer_fee method

pub fn expect_get_nft_serial(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_nft_serial method

pub fn expect_float_from_int(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_from_int method

pub fn expect_float_from_uint(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_from_uint method

pub fn expect_float_from_mant_exp(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_from_mant_exp method

pub fn expect_float_from_stamount(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_from_stamount method

pub fn expect_float_from_stnumber(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_from_stnumber method

pub fn expect_float_to_int(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_to_int method

pub fn expect_float_to_mant_exp(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_to_mant_exp method

pub fn expect_float_compare(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_compare method

pub fn expect_float_add(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_add method

pub fn expect_float_subtract(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_subtract method

pub fn expect_float_multiply(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_multiply method

pub fn expect_float_divide(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_divide method

pub fn expect_float_pow(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_pow method

pub fn expect_float_root(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_root method

pub fn expect_trace(&mut self) -> &mut Expectation

Create an Expectation for mocking the trace method

pub fn expect_trace_num(&mut self) -> &mut Expectation

Create an Expectation for mocking the trace_num method

pub fn expect_trace_account(&mut self) -> &mut Expectation

Create an Expectation for mocking the trace_account method

pub fn expect_trace_opaque_float(&mut self) -> &mut Expectation

Create an Expectation for mocking the trace_opaque_float method

pub fn expect_trace_amount(&mut self) -> &mut Expectation

Create an Expectation for mocking the trace_amount method